==> org.apache.sling.servlet-helpers-1.4.4-source-release.zip: org.apache.sling.servlet-helpers-1.4.4/src/main/java/org/apache/sling/servlethelpers/AdaptableUtil.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.servlethelpers;

import java.lang.reflect.Field;

import org.apache.sling.api.adapter.AdapterManager;
import org.apache.sling.api.adapter.SlingAdaptable;

final class AdaptableUtil {

    public static <AdapterType> AdapterType adaptToWithoutCaching(Object adaptable, Class<AdapterType> type) {
        AdapterManager adapterManager = getAdapterManager();
        if (adapterManager == null) {
            return null;
        }
        return adapterManager.getAdapter(adaptable, type);
    }

    /**
     * Get adapter manager via reflection.
     * @return Adapter manager instance
     */
    private static AdapterManager getAdapterManager() {
        try {
            Field adapterManagerStaticField = SlingAdaptable.class.getDeclaredField("ADAPTER_MANAGER");
            adapterManagerStaticField.setAccessible(true);
            return (AdapterManager)adapterManagerStaticField.get(null);
        }
        catch (NoSuchFieldException | IllegalArgumentException | IllegalAccessException ex) {
            throw new RuntimeException("Unable to get AdapterManager instance from SlingAdaptable via reflection.", ex);
        }
    }

}

==> org.apache.sling.servlet-helpers-2.0.0-source-release.zip: org.apache.sling.servlet-helpers-2.0.0/src/main/java/org/apache/sling/servlethelpers/AdaptableUtil.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.servlethelpers;

import java.lang.reflect.Field;

import org.apache.sling.api.adapter.AdapterManager;
import org.apache.sling.api.adapter.SlingAdaptable;

final class AdaptableUtil {

    private AdaptableUtil() {
        // to hide the public ctor
    }

    public static <T> T adaptToWithoutCaching(Object adaptable, Class<T> type) {
        AdapterManager adapterManager = getAdapterManager();
        if (adapterManager == null) {
            return null;
        }
        return adapterManager.getAdapter(adaptable, type);
    }

    /**
     * Get adapter manager via reflection.
     * @return Adapter manager instance
     */
    private static AdapterManager getAdapterManager() {
        try {
            Field adapterManagerStaticField = SlingAdaptable.class.getDeclaredField("ADAPTER_MANAGER");
            adapterManagerStaticField.setAccessible(true);
            return (AdapterManager) adapterManagerStaticField.get(null);
        } catch (NoSuchFieldException | IllegalArgumentException | IllegalAccessException ex) {
            throw new RuntimeException("Unable to get AdapterManager instance from SlingAdaptable via reflection.", ex);
        }
    }
}
